Compares requested prediction rows with the observed model-building support. It reports extrapolation and novel levels but never removes prediction rows.
Compares requested prediction rows with the observed model-building support. It reports extrapolation and novel levels but never removes prediction rows.