Estimate posterior peak pupil response inside a declared window
Source:R/pupil-estimands.R
estimate_pupil_peak.RdEstimate posterior peak pupil response inside a declared window
Examples
grid <- data.frame(.event_time = seq(0, 1, length.out = 5))
draws <- matrix(rnorm(500), nrow = 100)
prediction <- as_pupil_prediction_draws(draws, grid, "millimetres")
estimate_pupil_peak(prediction, c(0.2, 0.8))
#> <gp3bayes_pupil_estimand>
#> Estimand: peak
#> Rows: 1
#> Declared window: 0.2 to 0.8
#> Automatic significance decision: FALSE