Fit a pupil model through the fixed rstan route
Usage
fit_pupil_model(
specification,
chains = 4L,
iter = 2000L,
warmup = 1000L,
cores = min(2L, chains),
seed = 2026,
adapt_delta = 0.95,
max_treedepth = 12L,
refresh = 0L
)Fit a pupil model through the fixed rstan route
fit_pupil_model(
specification,
chains = 4L,
iter = 2000L,
warmup = 1000L,
cores = min(2L, chains),
seed = 2026,
adapt_delta = 0.95,
max_treedepth = 12L,
refresh = 0L
)