Aggregates posterior prediction draws over one or more columns already present in the prediction data.
Usage
group_prediction_summary(x, by, probs = c(0.025, 0.5, 0.975))Aggregates posterior prediction draws over one or more columns already present in the prediction data.
group_prediction_summary(x, by, probs = c(0.025, 0.5, 0.975))