Returns posterior location, uncertainty, R-hat, and ESS evidence for model parameters without converting them into psychological constructs.
Returns posterior location, uncertainty, R-hat, and ESS evidence for model parameters without converting them into psychological constructs.