Compute PSIS-LOO from a Log-Likelihood Matrix
Source:R/advanced-optional-workflows.R
compute_psis_loo_from_log_lik.RdThis function supports deterministic tests and advanced workflows that already possess pointwise log-likelihood draws.
R/advanced-optional-workflows.R
compute_psis_loo_from_log_lik.RdThis function supports deterministic tests and advanced workflows that already possess pointwise log-likelihood draws.