Collects reusable posterior, diagnostic, prediction, calibration, scoring, and optionally PSIS-LOO tables without making an automatic adequacy or model selection decision.
Usage
create_analysis_bundle(
fit,
newdata = NULL,
ndraws = 1000L,
include_group_effects = FALSE,
include_loo = FALSE
)