Creates a Cartesian prediction grid from declared model predictors. Numeric
covariates are held at an observed typical value unless values are supplied
explicitly through at.
Arguments
- x
A gp3bayes fit or approved model specification.
- variables
Optional variables to vary. By default the declared condition and non-identifier predictors are considered.
- at
Named list of explicit values for selected variables.
- numeric_at
One of
"median"or"mean"for numeric covariates not supplied inat.- max_rows
Maximum permitted grid size.
Value
A data frame suitable for predict_model().