Posterior Direction and ROPE Probability Table
Source:R/postfit-exploration.R
posterior_probability_table.RdPosterior Direction and ROPE Probability Table
Arguments
- x
A gp3bayes fit or posterior draws accepted by
posterior_interval_table().- variables, regex
Posterior variable selectors.
- rope
Optional two-element interval defining a region of practical equivalence. It is descriptive only.
Value
A data frame with posterior direction probabilities and, when requested, the posterior probability inside the supplied interval.
Examples
draws <- cbind(alpha = rnorm(500), beta = rnorm(500, 0.4))
posterior_probability_table(draws, rope = c(-0.1, 0.1))
#> variable probability_gt_zero probability_lt_zero probability_in_rope
#> alpha alpha 0.518 0.482 0.056
#> beta beta 0.660 0.340 0.090
#> rope_lower rope_upper
#> alpha -0.1 0.1
#> beta -0.1 0.1